@@ -1,29 +1,25 @@
 """
 Implements auth methods
 """
-from .constants import CLIENT
 from .err import OperationalError
-from .util import byte2int, int2byte
 
 
 try:
     from cryptography.hazmat.backends import default_backend
     from cryptography.hazmat.primitives import serialization, hashes
     from cryptography.hazmat.primitives.asymmetric import padding
+
     _have_cryptography = True
 except ImportError:
     _have_cryptography = False
 
 from functools import partial
 import hashlib
-import io
-import struct
-import warnings
 
 
 DEBUG = False
 SCRAMBLE_LENGTH = 20
-sha1_new = partial(hashlib.new, 'sha1')
+sha1_new = partial(hashlib.new, "sha1")
 
 
 # mysql_native_password
@@ -33,7 +29,7 @@ sha1_new = partial(hashlib.new, 'sha1')
 def scramble_native_password(password, message):
     """Scramble used for mysql_native_password"""
     if not password:
-        return b''
+        return b""
 
     stage1 = sha1_new(password).digest()
     stage2 = sha1_new(stage1).digest()
@@ -53,64 +49,6 @@ def _my_crypt(message1, message2):
     return bytes(result)
 
 
-# old_passwords support ported from libmysql/password.c
-# https://dev.mysql.com/doc/internals/en/old-password-authentication.html
-
-SCRAMBLE_LENGTH_323 = 8
-
-
-class RandStruct_323(object):
-
-    def __init__(self, seed1, seed2):
-        self.max_value = 0x3FFFFFFF
-        self.seed1 = seed1 % self.max_value
-        self.seed2 = seed2 % self.max_value
-
-    def my_rnd(self):
-        self.seed1 = (self.seed1 * 3 + self.seed2) % self.max_value
-        self.seed2 = (self.seed1 + self.seed2 + 33) % self.max_value
-        return float(self.seed1) / float(self.max_value)
-
-
-def scramble_old_password(password, message):
-    """Scramble for old_password"""
-    warnings.warn("old password (for MySQL <4.1) is used.  Upgrade your password with newer auth method.\n"
-                  "old password support will be removed in future PyMySQL version")
-    hash_pass = _hash_password_323(password)
-    hash_message = _hash_password_323(message[:SCRAMBLE_LENGTH_323])
-    hash_pass_n = struct.unpack(">LL", hash_pass)
-    hash_message_n = struct.unpack(">LL", hash_message)
-
-    rand_st = RandStruct_323(
-        hash_pass_n[0] ^ hash_message_n[0], hash_pass_n[1] ^ hash_message_n[1]
-    )
-    outbuf = io.BytesIO()
-    for _ in range(min(SCRAMBLE_LENGTH_323, len(message))):
-        outbuf.write(int2byte(int(rand_st.my_rnd() * 31) + 64))
-    extra = int2byte(int(rand_st.my_rnd() * 31))
-    out = outbuf.getvalue()
-    outbuf = io.BytesIO()
-    for c in out:
-        outbuf.write(int2byte(byte2int(c) ^ byte2int(extra)))
-    return outbuf.getvalue()
-
-
-def _hash_password_323(password):
-    nr = 1345345333
-    add = 7
-    nr2 = 0x12345671
-
-    # x in py3 is numbers, p27 is chars
-    for c in [byte2int(x) for x in password if x not in (' ', '\t', 32, 9)]:
-        nr ^= (((nr & 63) + add) * c) + (nr << 8) & 0xFFFFFFFF
-        nr2 = (nr2 + ((nr2 << 8) ^ nr)) & 0xFFFFFFFF
-        add = (add + c) & 0xFFFFFFFF
-
-    r1 = nr & ((1 << 31) - 1)  # kill sign bits
-    r2 = nr2 & ((1 << 31) - 1)
-    return struct.pack(">LL", r1, r2)
-
-
 # MariaDB's client_ed25519-plugin
 # https://mariadb.com/kb/en/library/connection/#client_ed25519-plugin
 
@@ -121,9 +59,12 @@ def _init_nacl():
     global _nacl_bindings
     try:
         from nacl import bindings
+
         _nacl_bindings = bindings
     except ImportError:
-        raise RuntimeError("'pynacl' package is required for ed25519_password auth method")
+        raise RuntimeError(
+            "'pynacl' package is required for ed25519_password auth method"
+        )
 
 
 def _scalar_clamp(s32):
@@ -198,8 +139,10 @@ def sha2_rsa_encrypt(password, salt, public_key):
     Used for sha256_password and caching_sha2_password.
     """
     if not _have_cryptography:
-        raise RuntimeError("'cryptography' package is required for sha256_password or caching_sha2_password auth methods")
-    message = _xor_password(password + b'\0', salt)
+        raise RuntimeError(
+            "'cryptography' package is required for sha256_password or caching_sha2_password auth methods"
+        )
+    message = _xor_password(password + b"\0", salt)
     rsa_key = serialization.load_pem_public_key(public_key, default_backend())
     return rsa_key.encrypt(
         message,
@@ -215,7 +158,7 @@ def sha256_password_auth(conn, pkt):
     if conn._secure:
         if DEBUG:
             print("sha256: Sending plain password")
-        data = conn.password + b'\0'
+        data = conn.password + b"\0"
         return _roundtrip(conn, data)
 
     if pkt.is_auth_switch_request():
@@ -224,12 +167,12 @@ def sha256_password_auth(conn, pkt):
             # Request server public key
             if DEBUG:
                 print("sha256: Requesting server public key")
-            pkt = _roundtrip(conn, b'\1')
+            pkt = _roundtrip(conn, b"\1")
 
     if pkt.is_extra_auth_data():
         conn.server_public_key = pkt._data[1:]
         if DEBUG:
-            print("Received public key:\n", conn.server_public_key.decode('ascii'))
+            print("Received public key:\n", conn.server_public_key.decode("ascii"))
 
     if conn.password:
         if not conn.server_public_key:
@@ -237,7 +180,7 @@ def sha256_password_auth(conn, pkt):
 
         data = sha2_rsa_encrypt(conn.password, conn.salt, conn.server_public_key)
     else:
-        data = b''
+        data = b""
 
     return _roundtrip(conn, data)
 
@@ -249,7 +192,7 @@ def scramble_caching_sha2(password, nonce):
     XOR(SHA256(password), SHA256(SHA256(SHA256(password)), nonce))
     """
     if not password:
-        return b''
+        return b""
 
     p1 = hashlib.sha256(password).digest()
     p2 = hashlib.sha256(p1).digest()
@@ -265,7 +208,7 @@ def scramble_caching_sha2(password, nonce):
 def caching_sha2_password_auth(conn, pkt):
     # No password fast path
     if not conn.password:
-        return _roundtrip(conn, b'')
+        return _roundtrip(conn, b"")
 
     if pkt.is_auth_switch_request():
         # Try from fast auth
@@ -305,10 +248,10 @@ def caching_sha2_password_auth(conn, pkt):
     if conn._secure:
         if DEBUG:
             print("caching sha2: Sending plain password via secure connection")
-        return _roundtrip(conn, conn.password + b'\0')
+        return _roundtrip(conn, conn.password + b"\0")
 
     if not conn.server_public_key:
-        pkt = _roundtrip(conn, b'\x02')  # Request public key
+        pkt = _roundtrip(conn, b"\x02")  # Request public key
         if not pkt.is_extra_auth_data():
             raise OperationalError(
                 "caching sha2: Unknown packet for public key: %s" % pkt._data[:1]
@@ -316,7 +259,7 @@ def caching_sha2_password_auth(conn, pkt):
 
         conn.server_public_key = pkt._data[1:]
         if DEBUG:
-            print(conn.server_public_key.decode('ascii'))
+            print(conn.server_public_key.decode("ascii"))
 
     data = sha2_rsa_encrypt(conn.password, conn.salt, conn.server_public_key)
     pkt = _roundtrip(conn, data)
