@@ -12,13 +12,14 @@ from . import err
 #: executemany only supports simple bulk insert.
 #: You can use it to load large dataset.
 RE_INSERT_VALUES = re.compile(
-    r"\s*((?:INSERT|REPLACE)\b.+\bVALUES?\s*)" +
-    r"(\(\s*(?:%s|%\(.+\)s)\s*(?:,\s*(?:%s|%\(.+\)s)\s*)*\))" +
-    r"(\s*(?:ON DUPLICATE.*)?);?\s*\Z",
-    re.IGNORECASE | re.DOTALL)
+    r"\s*((?:INSERT|REPLACE)\b.+\bVALUES?\s*)"
+    + r"(\(\s*(?:%s|%\(.+\)s)\s*(?:,\s*(?:%s|%\(.+\)s)\s*)*\))"
+    + r"(\s*(?:ON DUPLICATE.*)?);?\s*\Z",
+    re.IGNORECASE | re.DOTALL,
+)
 
 
-class Cursor(object):
+class Cursor:
     """
     This is the object you use to interact with the database.
 
@@ -49,7 +50,7 @@ class Cursor(object):
 
     def close(self):
         raise RuntimeError("You need to call 'await .aclose()'")
-        
+
     async def aclose(self):
         """
         Closing a cursor just exhausts all remaining data.
@@ -122,8 +123,6 @@ class Cursor(object):
         return x
 
     def _escape_args(self, args, conn):
-        ensure_bytes = partial(self._ensure_bytes, encoding=conn.encoding)
-
         if isinstance(args, (tuple, list)):
             return tuple(conn.literal(arg) for arg in args)
         elif isinstance(args, dict):
@@ -141,6 +140,7 @@ class Cursor(object):
         This method follows the extension to the DB API 2.0 followed by Psycopg.
         """
         conn = self._get_db()
+
         if args is not None:
             query = query % self._escape_args(args, conn)
 
@@ -188,11 +188,16 @@ class Cursor(object):
         if m:
             q_prefix = m.group(1) % ()
             q_values = m.group(2).rstrip()
-            q_postfix = m.group(3) or ''
-            assert q_values[0] == '(' and q_values[-1] == ')'
-            return await self._do_execute_many(q_prefix, q_values, q_postfix, args,
-                                         self.max_stmt_length,
-                                         self._get_db().encoding)
+            q_postfix = m.group(3) or ""
+            assert q_values[0] == "(" and q_values[-1] == ")"
+            return await self._do_execute_many(
+                q_prefix,
+                q_values,
+                q_postfix,
+                args,
+                self.max_stmt_length,
+                self._get_db().encoding,
+            )
 
         cnt = 0
         for arg in args:
@@ -200,7 +205,9 @@ class Cursor(object):
         self.rowcount = cnt
         return cnt
 
-    async def _do_execute_many(self, prefix, values, postfix, args, max_stmt_length, encoding):
+    async def _do_execute_many(
+        self, prefix, values, postfix, args, max_stmt_length, encoding
+    ):
         conn = self._get_db()
         escape = self._escape_args
         if isinstance(prefix, str):
@@ -211,18 +218,18 @@ class Cursor(object):
         args = iter(args)
         v = values % escape(next(args), conn)
         if isinstance(v, str):
-            v = v.encode(encoding, 'surrogateescape')
+            v = v.encode(encoding, "surrogateescape")
         sql += v
         rows = 0
         for arg in args:
             v = values % escape(arg, conn)
             if isinstance(v, str):
-                v = v.encode(encoding, 'surrogateescape')
+                v = v.encode(encoding, "surrogateescape")
             if len(sql) + len(v) + len(postfix) + 1 > max_stmt_length:
                 rows += await self.execute(sql + postfix)
                 sql = bytearray(prefix)
             else:
-                sql += b','
+                sql += b","
             sql += v
         rows += await self.execute(sql + postfix)
         self.rowcount = rows
@@ -258,14 +265,19 @@ class Cursor(object):
         """
         conn = self._get_db()
         if args:
-            fmt = '@_{0}_%d=%s'.format(procname)
-            await self._query('SET %s' % ','.join(fmt % (index, conn.escape(arg))
-                                            for index, arg in enumerate(args)))
+            fmt = f"@_{procname}_%d=%s"
+            await self._query(
+                "SET %s"
+                % ",".join(
+                    fmt % (index, conn.escape(arg)) for index, arg in enumerate(args)
+                )
+            )
             await self.nextset()
 
-        q = "CALL %s(%s)" % (procname,
-                             ','.join(['@_%s_%d' % (procname, i)
-                                       for i in range(len(args))]))
+        q = "CALL %s(%s)" % (
+            procname,
+            ",".join(["@_%s_%d" % (procname, i) for i in range(len(args))]),
+        )
         await self._query(q)
         self._executed = q
         return args
@@ -285,7 +297,7 @@ class Cursor(object):
         if self._rows is None:
             return ()
         end = self.rownumber + (size or self.arraysize)
-        result = self._rows[self.rownumber:end]
+        result = self._rows[self.rownumber : end]
         self.rownumber = min(end, len(self._rows))
         return result
 
@@ -295,7 +307,7 @@ class Cursor(object):
         if self._rows is None:
             return ()
         if self.rownumber:
-            result = self._rows[self.rownumber:]
+            result = self._rows[self.rownumber :]
         else:
             result = self._rows
         self.rownumber = len(self._rows)
@@ -304,7 +316,7 @@ class Cursor(object):
     def __iter__(self):
         if self._rows is None or self.rownumber:
             return self
-        return iter(self._rows) # optimization
+        return iter(self._rows)  # optimization
 
     def __next__(self):
         if self._rows is None or self.rownumber >= len(self._rows):
@@ -313,12 +325,8 @@ class Cursor(object):
         self.rownumber += 1
         return res
 
-    if sys.version_info < (3,5,2):
-        async def __aiter__(self):
-            return self
-    else:
-        def __aiter__(self):
-            return self
+    def __aiter__(self):
+        return self
 
     async def __anext__(self):
         if self._rows is None or self.rownumber >= len(self._rows):
@@ -326,12 +334,12 @@ class Cursor(object):
         res = self._rows[self.rownumber]
         self.rownumber += 1
         return res
-        
-    async def scroll(self, value, mode='relative'):
+
+    async def scroll(self, value, mode="relative"):
         self._check_executed()
-        if mode == 'relative':
+        if mode == "relative":
             r = self.rownumber + value
-        elif mode == 'absolute':
+        elif mode == "absolute":
             r = value
         else:
             raise err.ProgrammingError("unknown scroll mode %s" % mode)
@@ -367,10 +375,10 @@ class Cursor(object):
         self.lastrowid = result.insert_id
         self._rows = result.rows
         self._warnings_handled = False
- 
+
         if not self._defer_warnings:
             await self._show_warnings()
- 
+
     async def _show_warnings(self):
         if self._warnings_handled:
             return
@@ -399,7 +407,7 @@ class Cursor(object):
     NotSupportedError = err.NotSupportedError
 
 
-class DictCursorMixin(object):
+class DictCursorMixin:
     # You can override this to use OrderedDict or other dict-like types.
     dict_type = dict
 
@@ -410,7 +418,7 @@ class DictCursorMixin(object):
             for f in self._result.fields:
                 name = f.name
                 if name in fields:
-                    name = f.table_name + '.' + name
+                    name = f.table_name + "." + name
                 fields.append(name)
             self._fields = fields
 
@@ -528,21 +536,23 @@ class SSCursor(Cursor):
             self.rownumber += 1
         return rows
 
-    async def scroll(self, value, mode='relative'):
+    async def scroll(self, value, mode="relative"):
         self._check_executed()
 
-        if mode == 'relative':
+        if mode == "relative":
             if value < 0:
                 raise err.NotSupportedError(
-                        "Backwards scrolling not supported by this cursor")
+                    "Backwards scrolling not supported by this cursor"
+                )
 
             for _ in range(value):
                 await self.read_next()
             self.rownumber += value
-        elif mode == 'absolute':
+        elif mode == "absolute":
             if value < self.rownumber:
                 raise err.NotSupportedError(
-                    "Backwards scrolling not supported by this cursor")
+                    "Backwards scrolling not supported by this cursor"
+                )
 
             end = value - self.rownumber
             for _ in range(end):
